@@ -3,7 +3,6 @@ from datetime import datetime
 from dask.utils import format_bytes
 import toolz
 from tornado import escape
-from tornado import gen
 
 from ..utils import log_errors, format_time
 from .proxy import GlobalProxyHandler
@@ -28,6 +27,9 @@ class Workers(RequestHandler):
 class Worker(RequestHandler):
     def get(self, worker):
         worker = escape.url_unescape(worker)
+        if worker not in self.server.workers:
+            self.send_error(404)
+            return
         with log_errors():
             self.render(
                 "worker.html",
@@ -41,6 +43,9 @@ class Worker(RequestHandler):
 class Task(RequestHandler):
     def get(self, task):
         task = escape.url_unescape(task)
+        if task not in self.server.tasks:
+            self.send_error(404)
+            return
         with log_errors():
             self.render(
                 "task.html",
@@ -59,22 +64,20 @@ class Logs(RequestHandler):
 
 
 class WorkerLogs(RequestHandler):
-    @gen.coroutine
-    def get(self, worker):
+    async def get(self, worker):
         with log_errors():
             worker = escape.url_unescape(worker)
-            logs = yield self.server.get_worker_logs(workers=[worker])
+            logs = await self.server.get_worker_logs(workers=[worker])
             logs = logs[worker]
             self.render("logs.html", title="Logs: " + worker, logs=logs, **self.extra)
 
 
 class WorkerCallStacks(RequestHandler):
-    @gen.coroutine
-    def get(self, worker):
+    async def get(self, worker):
         with log_errors():
             worker = escape.url_unescape(worker)
             keys = self.server.processing[worker]
-            call_stack = yield self.server.get_call_stack(keys=keys)
+            call_stack = await self.server.get_call_stack(keys=keys)
             self.render(
                 "call-stack.html",
                 title="Call Stacks: " + worker,
@@ -84,11 +87,10 @@ class WorkerCallStacks(RequestHandler):
 
 
 class TaskCallStack(RequestHandler):
-    @gen.coroutine
-    def get(self, key):
+    async def get(self, key):
         with log_errors():
             key = escape.url_unescape(key)
-            call_stack = yield self.server.get_call_stack(keys=[key])
+            call_stack = await self.server.get_call_stack(keys=[key])
             if not call_stack:
                 self.write(
                     "<p>Task not actively running. "
@@ -184,14 +186,24 @@ class _PrometheusCollector(object):
 
         yield GaugeMetricFamily(
             "dask_scheduler_workers",
-            "Number of workers.",
+            "Number of workers connected.",
             value=len(self.server.workers),
         )
         yield GaugeMetricFamily(
             "dask_scheduler_clients",
-            "Number of clients.",
+            "Number of clients connected.",
             value=len(self.server.clients),
         )
+        yield GaugeMetricFamily(
+            "dask_scheduler_received_tasks",
+            "Number of tasks received at scheduler",
+            value=len(self.server.tasks),
+        )
+        yield GaugeMetricFamily(
+            "dask_scheduler_unrunnable_tasks",
+            "Number of unrunnable tasks at scheduler",
+            value=len(self.server.unrunnable),
+        )
 
 
 class PrometheusHandler(RequestHandler):
