@@ -1,10 +1,8 @@
-from __future__ import print_function, division, absolute_import
-
 from ..utils import ignoring
 
 from .cluster import Cluster
 from .local import LocalCluster
-from .spec import SpecCluster
+from .spec import SpecCluster, ProcessInterface
 from .adaptive import Adaptive
 
 with ignoring(ImportError):
