@@ -1,12 +1,9 @@
-from __future__ import print_function, division, absolute_import
-
 import sys
 from zlib import crc32
 
 import numpy as np
 import pytest
 
-from distributed.compatibility import PY2
 from distributed.protocol import (
     serialize,
     deserialize,
@@ -79,7 +76,7 @@ def test_dumps_serialize_numpy(x):
     header, frames = serialize(x)
     if "compression" in header:
         frames = decompress(header, frames)
-    buffer_interface = buffer if PY2 else memoryview  # noqa: F821
+    buffer_interface = memoryview
     for frame in frames:
         assert isinstance(frame, (bytes, buffer_interface))
     y = deserialize(header, frames)
@@ -107,7 +104,7 @@ def test_dumps_serialize_numpy(x):
     ],
 )
 def test_serialize_numpy_ma_masked_array(x):
-    y, = loads(dumps([to_serialize(x)]))
+    (y,) = loads(dumps([to_serialize(x)]))
     assert x.data.dtype == y.data.dtype
     np.testing.assert_equal(x.data, y.data)
     np.testing.assert_equal(x.mask, y.mask)
@@ -115,7 +112,7 @@ def test_serialize_numpy_ma_masked_array(x):
 
 
 def test_serialize_numpy_ma_masked():
-    y, = loads(dumps([to_serialize(np.ma.masked)]))
+    (y,) = loads(dumps([to_serialize(np.ma.masked)]))
     assert y is np.ma.masked
 
 
@@ -126,8 +123,8 @@ def test_dumps_serialize_numpy_custom_dtype():
     rational = test_rational.rational
     try:
         builtins.rational = (
-            rational
-        )  # Work around https://github.com/numpy/numpy/issues/9160
+            rational  # Work around https://github.com/numpy/numpy/issues/9160
+        )
         x = np.array([1], dtype=rational)
         header, frames = serialize(x)
         y = deserialize(header, frames)
