@@ -1,12 +1,10 @@
-from __future__ import print_function, division, absolute_import
-
 from collections import defaultdict
 import datetime
 import logging
 import uuid
 
-from tornado import gen
 import tornado.queues
+from tornado.locks import Event
 
 from .client import Future, _get_global_client, Client
 from .utils import tokey, sync, thread_state
@@ -49,6 +47,7 @@ class QueueExtension(object):
         self.scheduler.extensions["queues"] = self
 
     def create(self, stream=None, name=None, client=None, maxsize=0):
+        print("name", name)
         if name not in self.queues:
             self.queues[name] = tornado.queues.Queue(maxsize=maxsize)
             self.client_refcount[name] = 1
@@ -64,13 +63,11 @@ class QueueExtension(object):
             del self.client_refcount[name]
             futures = self.queues[name]._queue
             del self.queues[name]
-            self.scheduler.client_releases_keys(
-                keys=[d["value"] for d in futures if d["type"] == "Future"],
-                client="queue-%s" % name,
-            )
+            keys = [d["value"] for d in futures if d["type"] == "Future"]
+            if keys:
+                self.scheduler.client_releases_keys(keys=keys, client="queue-%s" % name)
 
-    @gen.coroutine
-    def put(
+    async def put(
         self, stream=None, name=None, key=None, data=None, client=None, timeout=None
     ):
         if key is not None:
@@ -80,8 +77,8 @@ class QueueExtension(object):
         else:
             record = {"type": "msgpack", "value": data}
         if timeout is not None:
-            timeout = datetime.timedelta(seconds=(timeout))
-        yield self.queues[name].put(record, timeout=timeout)
+            timeout = datetime.timedelta(seconds=timeout)
+        await self.queues[name].put(record, timeout=timeout)
 
     def future_release(self, name=None, key=None, client=None):
         self.future_refcount[name, key] -= 1
@@ -89,8 +86,7 @@ class QueueExtension(object):
             self.scheduler.client_releases_keys(keys=[key], client="queue-%s" % name)
             del self.future_refcount[name, key]
 
-    @gen.coroutine
-    def get(self, stream=None, name=None, client=None, timeout=None, batch=False):
+    async def get(self, stream=None, name=None, client=None, timeout=None, batch=False):
         def process(record):
             """ Add task status if known """
             if record["type"] == "Future":
@@ -111,7 +107,7 @@ class QueueExtension(object):
             out = []
             if batch is True:
                 while not q.empty():
-                    record = yield q.get()
+                    record = await q.get()
                     out.append(record)
             else:
                 if timeout is not None:
@@ -121,16 +117,16 @@ class QueueExtension(object):
                     )
                     raise NotImplementedError(msg)
                 for i in range(batch):
-                    record = yield q.get()
+                    record = await q.get()
                     out.append(record)
             out = [process(o) for o in out]
-            raise gen.Return(out)
+            return out
         else:
             if timeout is not None:
                 timeout = datetime.timedelta(seconds=timeout)
-            record = yield self.queues[name].get(timeout=timeout)
+            record = await self.queues[name].get(timeout=timeout)
             record = process(record)
-            raise gen.Return(record)
+            return record
 
     def qsize(self, stream=None, name=None, client=None):
         return self.queues[name].qsize()
@@ -168,12 +164,18 @@ class Queue(object):
     def __init__(self, name=None, client=None, maxsize=0):
         self.client = client or _get_global_client()
         self.name = name or "queue-" + uuid.uuid4().hex
+        self._event_started = Event()
         if self.client.asynchronous or getattr(
             thread_state, "on_event_loop_thread", False
         ):
-            self._started = self.client.scheduler.queue_create(
-                name=self.name, maxsize=maxsize
-            )
+
+            async def _create_queue():
+                await self.client.scheduler.queue_create(
+                    name=self.name, maxsize=maxsize
+                )
+                self._event_started.set()
+
+            self.client.loop.add_callback(_create_queue)
         else:
             sync(
                 self.client.loop,
@@ -181,24 +183,22 @@ class Queue(object):
                 name=self.name,
                 maxsize=maxsize,
             )
-            self._started = gen.moment
+            self._event_started.set()
 
     def __await__(self):
-        @gen.coroutine
-        def _():
-            yield self._started
-            raise gen.Return(self)
+        async def _():
+            await self._event_started.wait()
+            return self
 
         return _().__await__()
 
-    @gen.coroutine
-    def _put(self, value, timeout=None):
+    async def _put(self, value, timeout=None):
         if isinstance(value, Future):
-            yield self.client.scheduler.queue_put(
+            await self.client.scheduler.queue_put(
                 key=tokey(value.key), timeout=timeout, name=self.name
             )
         else:
-            yield self.client.scheduler.queue_put(
+            await self.client.scheduler.queue_put(
                 data=value, timeout=timeout, name=self.name
             )
 
@@ -224,9 +224,8 @@ class Queue(object):
         """ Current number of elements in the queue """
         return self.client.sync(self._qsize, **kwargs)
 
-    @gen.coroutine
-    def _get(self, timeout=None, batch=False):
-        resp = yield self.client.scheduler.queue_get(
+    async def _get(self, timeout=None, batch=False):
+        resp = await self.client.scheduler.queue_get(
             timeout=timeout, name=self.name, batch=batch
         )
 
@@ -248,12 +247,11 @@ class Queue(object):
         else:
             result = list(map(process, resp))
 
-        raise gen.Return(result)
+        return result
 
-    @gen.coroutine
-    def _qsize(self):
-        result = yield self.client.scheduler.queue_qsize(name=self.name)
-        raise gen.Return(result)
+    async def _qsize(self):
+        result = await self.client.scheduler.queue_qsize(name=self.name)
+        return result
 
     def close(self):
         if self.client.status == "running":  # TODO: can leave zombie futures
