@@ -41,7 +41,6 @@ from tornado.ioloop import IOLoop
 from .client import default_client, _global_clients, Client
 from .compatibility import WINDOWS
 from .comm import Comm
-from .comm.utils import offload
 from .config import initialize_logging
 from .core import connect, rpc, CommClosedError
 from .deploy import SpecCluster
@@ -60,6 +59,7 @@ from .utils import (
     sync,
     iscoroutinefunction,
     thread_state,
+    _offload_executor,
 )
 from .worker import Worker, TOTAL_MEMORY
 from .nanny import Nanny
@@ -80,7 +80,7 @@ logging_levels = {
 }
 
 
-offload(lambda: None).result()  # create thread during import
+_offload_executor.submit(lambda: None).result()  # create thread during import
 
 
 @pytest.fixture(scope="session")
@@ -636,7 +636,7 @@ def cluster(
             q = mp_context.Queue()
             fn = "_test_worker-%s" % uuid.uuid4()
             kwargs = merge(
-                {"nthreads": 1, "local_dir": fn, "memory_limit": TOTAL_MEMORY},
+                {"nthreads": 1, "local_directory": fn, "memory_limit": TOTAL_MEMORY},
                 worker_kwargs,
             )
             proc = mp_context.Process(
@@ -1447,21 +1447,24 @@ def check_thread_leak():
 
 
 @contextmanager
-def check_process_leak():
+def check_process_leak(check=True):
     for proc in mp_context.active_children():
         proc.terminate()
 
     yield
 
-    for i in range(100):
-        if not set(mp_context.active_children()):
-            break
+    if check:
+        for i in range(100):
+            if not set(mp_context.active_children()):
+                break
+            else:
+                sleep(0.2)
         else:
-            sleep(0.2)
-    else:
-        assert not mp_context.active_children()
+            assert not mp_context.active_children()
 
     _cleanup_dangling()
+    for proc in mp_context.active_children():
+        proc.terminate()
 
 
 @contextmanager
@@ -1524,7 +1527,7 @@ def clean(threads=not WINDOWS, instances=True, timeout=1, processes=True):
 
     with check_thread_leak() if threads else null():
         with pristine_loop() as loop:
-            with check_process_leak() if processes else null():
+            with check_process_leak(check=processes):
                 with check_instances() if instances else null():
                     with check_active_rpc(loop, timeout):
                         reset_config()
